# ccxt-unmerged
Exchanges whose open PRs haven't been merged into ccxt yet.

```
import ccxt_unmerged
import ccxt

krakenfu = ccxt.krakenfu()
```

## List of exchanges
_58coin<br/>
bcio<br/>
beaxy<br/>
biki<br/>
bitbns<br/>
bitclude<br/>
bitforexfu<br/>
bitkub<br/>
bitopro<br/>
bitrue<br/>
bitzfu<br/>
bkex<br/>
btse<br/>
ceo<br/>
changellypro<br/>
coinbene<br/>
coindcx<br/>
coinsuper<br/>
cossdex<br/>
cryptocom<br/>
dragonex<br/>
duedex<br/>
felixo<br/>
foblgate<br/>
gateiofu<br/>
krakenfu<br/>
multi<br/>
mxc<br/>
nominex<br/>
primexbt<br/>
remitano<br/>
silgonex<br/>
slicex<br/>
tokenomy<br/>
tokensnet<br/>
tradeogre<br/>
txbit<br/>
vinex<br/>
vitex<br/>
wazirx<br/>
yunex<br/>
